@@ -1,4 +1,4 @@
-package Dist::Zilla::PluginBundle::RJBS 5.017;
+package Dist::Zilla::PluginBundle::RJBS 5.018;
 # ABSTRACT: BeLike::RJBS when you build your dists
 
 use Moose;
@@ -10,6 +10,7 @@ with
 
 use v5.20.0;
 use experimental 'postderef'; # Not really an experiment anymore.
+use utf8;
 
 #pod =head1 DESCRIPTION
 #pod
@@ -64,12 +65,32 @@ use Dist::Zilla::PluginBundle::Basic;
 use Dist::Zilla::PluginBundle::Filter;
 use Dist::Zilla::PluginBundle::Git;
 
-package Dist::Zilla::Plugin::RJBSMisc 5.017 {
+package Dist::Zilla::Plugin::RJBSMisc 5.018 {
   use Moose;
   with 'Dist::Zilla::Role::BeforeBuild',
-       'Dist::Zilla::Role::AfterBuild';
+       'Dist::Zilla::Role::AfterBuild',
+       'Dist::Zilla::Role::MetaProvider',
+       'Dist::Zilla::Role::PrereqSource';
 
   has perl_support => (is => 'ro');
+  has package_name_version => (is => 'ro');
+
+  sub metadata {
+    my ($self) = @_;
+
+    return { x_rjbs_perl_support => $self->perl_support };
+  }
+
+  sub register_prereqs {
+    my ($self) = @_;
+
+    if ($self->package_name_version) {
+      $self->zilla->register_prereqs(
+        { phase => 'runtime', type => 'requires' },
+        perl => '5.012',
+      );
+    }
+  }
 
   sub before_build {
     my ($self) = @_;
@@ -77,6 +98,10 @@ package Dist::Zilla::Plugin::RJBSMisc 5.017 {
     if (($self->perl_support // '') eq 'toolchain' && $self->package_name_version) {
       $self->log_fatal('This dist claims to be toolchain but uses "package NAME VERSION"');
     }
+
+    unless (defined $self->perl_support) {
+      $self->log("❗️ did not set perl-support!");
+    }
   }
 
   sub after_build {
@@ -155,12 +180,32 @@ has package_name_version => (
   is      => 'ro',
   isa     => 'Bool',
   lazy    => 1,
-  default => sub { $_[0]->payload->{package_name_version} // 1 },
+  default => sub { $_[0]->payload->{package_name_version}
+                // $_[0]->payload->{'package-name-version'}
+                // 1
+  },
 );
 
 has perl_support => (
   is      => 'ro',
-  default => sub { $_[0]->payload->{perl_support} },
+  lazy    => 1,
+  default => sub {
+    # XXX: Fix this better.
+    # See, we have all these mvp aliases to convert foo-bar to foo_bar, but
+    # those aliases aren't run on the bundle options when passed through a
+    # @Filter.  So:
+    #
+    # [@Filter]
+    # -bundle = @RJBS
+    # perl-support = no-mercy
+    #
+    # ...didn't work, because the payload had 'perl-support' and not
+    # 'perl_support'.  Probably this aliasing should happen during the @Filter
+    # process, but it's kind of a hot mess in here.  This key is the most
+    # important one, and this comment is here to remind me what happened if I
+    # ever hear this on some other library.
+    $_[0]->payload->{perl_support} // $_[0]->payload->{'perl-support'}
+  },
 );
 
 sub configure {
@@ -181,6 +226,7 @@ sub configure {
     [ PromptIfStale => 'CPAN-Outdated' => {
       phase => 'release',
       check_all_plugins => 1,
+      skip  => [ 'Dist::Zilla::Plugin::RJBSMisc' ],
       # check_all_prereqs => 1, # <-- not sure yet -- rjbs, 2013-09-23
     } ],
   );
@@ -260,7 +306,10 @@ sub configure {
 
   $self->add_plugins(
     [ RJBSMisc => {
-        perl_support => $self->perl_support,
+        map {; $_ => scalar $self->$_ } qw(
+          package_name_version
+          perl_support
+        )
     } ],
   );
 
@@ -299,7 +348,7 @@ Dist::Zilla::PluginBundle::RJBS - BeLike::RJBS when you build your dists
 
 =head1 VERSION
 
-version 5.017
+version 5.018
 
 =head1 DESCRIPTION
 
